Documentation
¶
Overview ¶
gonet is a simple go network tool that prints information about your system, cpu information, memory usage, disk usage, network interfaces & MAC address.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReadMetrics ¶
func ReadMetrics() sysMetrics
ReadMetrics reads metrics from the system and returns a Metrics struct
func WriteMetrics ¶
WriteMetrics writes metrics to the given writer. If writer is nil, it will write to stdout
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.